import { actionResult, askLogCreate, EventActionType, getProcessCustomImplementation, LogLevelEnum, } from 'quidproquo-core';
import { randomGuid } from '../../../../../awsLambdaUtils';
export function* askTransformResponseStory({ eventParams, qpqEventRecordResponses: [record], }) {
    if (!record.success) {
        yield* askLogCreate(LogLevelEnum.Fatal, record.error.errorText, record.error.errorStack);
    }
    return {
        statusCode: 500,
    };
}
const getProcessTransformResponseResult = (qpqConfig) => {
    // Create a custom runtime for errored responses so we can log them out
    const errorCustomImplementation = getProcessCustomImplementation(qpqConfig, askTransformResponseStory, 'Transform Errored Websocket Response', null, () => new Date().toISOString(), randomGuid);
    return async (payload, session, actionProcessors, logger, updateSession, dynamicModuleLoader) => {
        if (payload.qpqEventRecordResponses.some((r) => !r.success)) {
            // We only wan't to run this for errors, because a custom imp is slower then a regular imp
            return await errorCustomImplementation(payload, session, actionProcessors, logger, updateSession, dynamicModuleLoader);
        }
        return actionResult({
            statusCode: 200,
        });
    };
};
export const getEventTransformResponseResultActionProcessor = async (qpqConfig) => ({
    [EventActionType.TransformResponseResult]: getProcessTransformResponseResult(qpqConfig),
});
